==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/ro.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Vizualizator",
    "Simple file viewer with slideshow for media" : "Vizualizator simplu de fișiere cu derulator media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Afișează cele mai recente fotografii și videoclipuri din vacanță ca în filme, arată un fragment al ultimului tău roman direct din cloud, alege cel mai bun GIF al colecției tale datorită previzualizării directe a fișierelor tale favorite și multe altele!",
    "Your browser does not support audio." : "Browser-ul tău nu suportă audio.",
    "Error loading {name}" : "Eroare la încărcare {name}",
    "Unsaved changes" : "Modificări nesalvate",
    "Your browser does not support videos." : "Browser-ul tău nu suportă video.",
    "Edit" : "Editează",
    "Open sidebar" : "Deschide bara laterală",
    "Download" : "Descărcare",
    "Delete" : "Șterge",
    "There is no plugin available to display this file type" : "Nu există nici un supliment (plugin) disponibil pentru a afișa acest tip de fișier",
    "View" : "Vizualizare",
    "Name" : "Nume",
    "Save" : "Salvează",
    "Back" : "Înapoi",
    "Loading …" : "Se încarcă…",
    "Reset" : "Resetare",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "Undo" : "Anulează ultima acțiune",
    "Custom" : "Particularizat",
    "Text" : "Text",
    "Size" : "Mărime",
    "Position" : "Poziție"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-25.0.4.tgz: nextcloud/apps/viewer/l10n/ro.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Vizualizator",
    "Simple file viewer with slideshow for media" : "Vizualizator simplu de fișiere cu derulator media",
    "Your browser does not support audio." : "Browser-ul tău nu suportă audio.",
    "Error loading {name}" : "Eroare la încărcare {name}",
    "Image saved" : "Imagine salvată",
    "Unsaved changes" : "Modificări nesalvate",
    "Your browser does not support videos." : "Browser-ul tău nu suportă video.",
    "Edit" : "Editează",
    "Open sidebar" : "Deschide bara laterală",
    "Download" : "Descărcare",
    "Delete" : "Șterge",
    "There is no plugin available to display this file type" : "Nu există nici un supliment (plugin) disponibil pentru a afișa acest tip de fișier",
    "View" : "Vizualizare",
    "Name" : "Nume",
    "Save" : "Salvează",
    "Back" : "Înapoi",
    "Loading …" : "Se încarcă…",
    "Reset" : "Resetare",
    "Cancel" : "Anulare",
    "Continue" : "Continuă",
    "Undo" : "Anulează ultima acțiune",
    "Custom" : "Particularizat",
    "Text" : "Text",
    "Size" : "Mărime",
    "Position" : "Poziție",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Afișează cele mai recente fotografii și videoclipuri din vacanță ca în filme, arată un fragment al ultimului tău roman direct din cloud, alege cel mai bun GIF al colecției tale datorită previzualizării directe a fișierelor tale favorite și multe altele!"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
